@@ -1,5 +1,5 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Form;
-$CatalystX::Resource::TraitFor::Controller::Resource::Form::VERSION = '0.02';
+$CatalystX::Resource::TraitFor::Controller::Resource::Form::VERSION = '0.03';
 use MooseX::MethodAttributes::Role;
 use MooseX::Types::LoadableClass qw/ LoadableClass /;
 use namespace::autoclean;
@@ -52,13 +52,10 @@ sub form {
        %$form_attrs_process,
     );
 
-    if ( $self->has_form_template ) {
-        $c->stash( template => $self->form_template, form => $form );
-    }
-    else {
-        my $rendered_form = $form->render;
-        $c->stash( template => \$rendered_form );
-    }
+    my $template = $self->has_form_template
+                   ? $self->form_template  # path to tt file
+                   : \'[% form.render %]'; # ref to inline template string
+    $c->stash( template => $template, form => $form );
 
     return unless $form->validated;
 
@@ -88,7 +85,7 @@ CatalystX::Resource::TraitFor::Controller::Resource::Form - handles form related
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 ATTRIBUTES
 
